==> ginkgo-hpc-docs-1.10.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/all_1b.js <==
var searchData=
[
  ['u_5fsolver_5ffactory_0',['u_solver_factory',['../structgko_1_1preconditioner_1_1Ilu_1_1parameters__type.html#a61f96b7a91dff2e5684567bd9c422cee',1,'gko::preconditioner::Ilu::parameters_type']]],
  ['u_5fstrategy_1',['u_strategy',['../structgko_1_1factorization_1_1Ilu_1_1parameters__type.html#ae39206eef0cd32835df5b636e1a60236',1,'gko::factorization::Ilu::parameters_type::u_strategy'],['../structgko_1_1factorization_1_1ParIlu_1_1parameters__type.html#afb44e05b0d0df2a56589f5986a7c4539',1,'gko::factorization::ParIlu::parameters_type::u_strategy'],['../structgko_1_1factorization_1_1ParIlut_1_1parameters__type.html#a67d30ba48b75f7a386383e9a5c1bbfc2',1,'gko::factorization::ParIlut::parameters_type::u_strategy']]],
  ['uint16_2',['uint16',['../namespacegko.html#af07ab7e285d68cde5e10f9c4ed642213',1,'gko']]],
  ['uint32_3',['uint32',['../namespacegko.html#a7cf056fa904140b50658e0637fba428c',1,'gko']]],
  ['uint64_4',['uint64',['../namespacegko.html#a09ee89da532d8b1fa6fdecec2d20b9bf',1,'gko']]],
  ['uint8_5',['uint8',['../namespacegko.html#a06d96f1ecdca6b86399173969771c3fb',1,'gko']]],
  ['uintptr_6',['uintptr',['../namespacegko.html#a70648f1299a0c1297e2bf86f47264626',1,'gko']]],
  ['unary_5fminus_7',['unary_minus',['../structgko_1_1accessor_1_1unary__minus.html',1,'gko::accessor']]],
  ['unary_5fplus_8',['unary_plus',['../structgko_1_1accessor_1_1unary__plus.html',1,'gko::accessor']]],
  ['unit_20tests_9',['Running the unit tests',['../testing_ginkgo.html#autotoc_md7',1,'']]],
  ['unit_5fdiagonal_10',['unit_diagonal',['../structgko_1_1solver_1_1LowerTrs_1_1parameters__type.html#a5777aed3bffc9bdef27c6bcb1cd414f9',1,'gko::solver::LowerTrs::parameters_type::unit_diagonal'],['../structgko_1_1solver_1_1UpperTrs_1_1parameters__type.html#a94cbdba6732b08966b948a7bdb368b50',1,'gko::solver::UpperTrs::parameters_type::unit_diagonal']]],
  ['unit_5froot_11',['unit_root',['../namespacegko.html#a7d18aa213befc4d1dac5dbc8eeed6e7d',1,'gko']]],
  ['unlock_12',['unlock',['../classgko_1_1experimental_1_1mpi_1_1window.html#a8007809ea63aa789c2e3eae7b512e683',1,'gko::experimental::mpi::window']]],
  ['unlock_5fall_13',['unlock_all',['../classgko_1_1experimental_1_1mpi_1_1window.html#a8d34b976309b2958d973d1d68acf627d',1,'gko::experimental::mpi::window']]],
  ['unpack_14',['unpack',['../classgko_1_1experimental_1_1factorization_1_1Factorization.html#ad0163a75274ff8054cc4d93732d82501',1,'gko::experimental::factorization::Factorization']]],
  ['unsupportedmatrixproperty_15',['UnsupportedMatrixProperty',['../classgko_1_1UnsupportedMatrixProperty.html',1,'gko::UnsupportedMatrixProperty'],['../classgko_1_1UnsupportedMatrixProperty.html#a38d858283d1e7e4a852c93baf79e7217',1,'gko::UnsupportedMatrixProperty::UnsupportedMatrixProperty()']]],
  ['update_16',['update',['../classgko_1_1stop_1_1Criterion.html#a47e22c46eaa742d709dcbf0d26d93e6c',1,'gko::stop::Criterion']]],
  ['update_5fvalues_17',['update_values',['../structgko_1_1matrix_1_1Csr_1_1permuting__reuse__info.html#a335568a4da6c11cff5dc7adbd347b4ce',1,'gko::matrix::Csr::permuting_reuse_info']]],
  ['updater_18',['Updater',['../classgko_1_1stop_1_1Criterion_1_1Updater.html',1,'gko::stop::Criterion::Updater'],['../classgko_1_1stop_1_1Criterion_1_1Updater.html#aa8356e2fbfaf46cab62d8f8a905ab8bd',1,'gko::stop::Criterion::Updater::Updater()']]],
  ['uppertrs_19',['UpperTrs',['../classgko_1_1solver_1_1UpperTrs.html',1,'gko::solver::UpperTrs&lt; ValueType, IndexType &gt;'],['../classgko_1_1solver_1_1UpperTrs.html#a9fc8a602b284e8923b6a30135c84c437',1,'gko::solver::UpperTrs::UpperTrs(const UpperTrs &amp;)'],['../classgko_1_1solver_1_1UpperTrs.html#a97322e2b1e6bcce67f074f7fc5dd7cd1',1,'gko::solver::UpperTrs::UpperTrs(UpperTrs &amp;&amp;)']]],
  ['uppertrs_3c_20value_5ftype_2c_20index_5ftype_20_3e_20',['UpperTrs&lt; value_type, index_type &gt;',['../classgko_1_1solver_1_1UpperTrs.html',1,'gko::solver']]],
  ['uppertrs_3c_20valuetype_2c_20indextype_20_3e_21',['UpperTrs&lt; ValueType, IndexType &gt;',['../classgko_1_1solver_1_1UpperTrs.html',1,'gko::solver']]],
  ['usage_22',['Advantages of this approach and usage',['../group__LinOp.html#linop_3',1,'']]],
  ['use_20of_20macros_20vs_20functions_23',['Use of macros vs functions',['../contributing_guidelines.html#autotoc_md49',1,'']]],
  ['usecomposition_24',['UseComposition',['../classgko_1_1UseComposition.html',1,'gko']]],
  ['usecomposition_3c_20default_5fprecision_20_3e_25',['UseComposition&lt; default_precision &gt;',['../classgko_1_1UseComposition.html',1,'gko']]],
  ['usecomposition_3c_20valuetype_20_3e_26',['UseComposition&lt; ValueType &gt;',['../classgko_1_1UseComposition.html',1,'gko']]],
  ['user_27',['user',['../namespacegko_1_1log.html#a15f71654c6c4f4defc95f9359343fa27aee11cbb19052e40b07aac0ca060c23ee',1,'gko::log']]],
  ['user_5frange_28',['user_range',['../classgko_1_1log_1_1ProfilerHook.html#a4d0e1e93d993f5074d60276359faadd8',1,'gko::log::ProfilerHook']]],
  ['using_20batchcg_20in_20ginkgo_29',['Example: using BatchCG in Ginkgo',['../classgko_1_1batch_1_1BatchLinOpFactory.html#autotoc_md71',1,'']]],
  ['using_20cg_20in_20ginkgo_30',['Example: using CG in Ginkgo',['../classgko_1_1LinOpFactory.html#autotoc_md74',1,'']]],
  ['using_20ctest_31',['Using CTest',['../testing_ginkgo.html#autotoc_md10',1,'']]],
  ['using_20library_20classes_32',['Using library classes',['../contributing_guidelines.html#autotoc_md22',1,'']]],
  ['using_20make_20quick_5ftest_33',['Using make quick_test',['../testing_ginkgo.html#autotoc_md9',1,'']]],
  ['using_20make_20test_34',['Using make test',['../testing_ginkgo.html#autotoc_md8',1,'']]],
  ['using_20ssget_20to_20fetch_20the_20matrices_35',['2: Using ssget to fetch the matrices',['../benchmarking_ginkgo.html#autotoc_md12',1,'']]]
];

==> ginkgo-hpc-docs-1.11.0-3-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/all_1b.js <==
var searchData=
[
  ['u_5fsolver_5ffactory_0',['u_solver_factory',['../structgko_1_1preconditioner_1_1Ilu_1_1parameters__type.html#a61f96b7a91dff2e5684567bd9c422cee',1,'gko::preconditioner::Ilu::parameters_type']]],
  ['u_5fstrategy_1',['u_strategy',['../structgko_1_1factorization_1_1Ilu_1_1parameters__type.html#ae39206eef0cd32835df5b636e1a60236',1,'gko::factorization::Ilu::parameters_type::u_strategy'],['../structgko_1_1factorization_1_1ParIlu_1_1parameters__type.html#afb44e05b0d0df2a56589f5986a7c4539',1,'gko::factorization::ParIlu::parameters_type::u_strategy'],['../structgko_1_1factorization_1_1ParIlut_1_1parameters__type.html#a67d30ba48b75f7a386383e9a5c1bbfc2',1,'gko::factorization::ParIlut::parameters_type::u_strategy']]],
  ['uint16_2',['uint16',['../namespacegko.html#af07ab7e285d68cde5e10f9c4ed642213',1,'gko']]],
  ['uint32_3',['uint32',['../namespacegko.html#a7cf056fa904140b50658e0637fba428c',1,'gko']]],
  ['uint64_4',['uint64',['../namespacegko.html#a09ee89da532d8b1fa6fdecec2d20b9bf',1,'gko']]],
  ['uint8_5',['uint8',['../namespacegko.html#a06d96f1ecdca6b86399173969771c3fb',1,'gko']]],
  ['uintptr_6',['uintptr',['../namespacegko.html#a70648f1299a0c1297e2bf86f47264626',1,'gko']]],
  ['unary_5fminus_7',['unary_minus',['../structgko_1_1accessor_1_1unary__minus.html',1,'gko::accessor']]],
  ['unary_5fplus_8',['unary_plus',['../structgko_1_1accessor_1_1unary__plus.html',1,'gko::accessor']]],
  ['unit_20tests_9',['Running the unit tests',['../testing_ginkgo.html#autotoc_md7',1,'']]],
  ['unit_5fdiagonal_10',['unit_diagonal',['../structgko_1_1solver_1_1LowerTrs_1_1parameters__type.html#a5777aed3bffc9bdef27c6bcb1cd414f9',1,'gko::solver::LowerTrs::parameters_type::unit_diagonal'],['../structgko_1_1solver_1_1UpperTrs_1_1parameters__type.html#a94cbdba6732b08966b948a7bdb368b50',1,'gko::solver::UpperTrs::parameters_type::unit_diagonal']]],
  ['unit_5froot_11',['unit_root',['../namespacegko.html#a7d18aa213befc4d1dac5dbc8eeed6e7d',1,'gko']]],
  ['unlock_12',['unlock',['../classgko_1_1experimental_1_1mpi_1_1window.html#a8007809ea63aa789c2e3eae7b512e683',1,'gko::experimental::mpi::window']]],
  ['unlock_5fall_13',['unlock_all',['../classgko_1_1experimental_1_1mpi_1_1window.html#a8d34b976309b2958d973d1d68acf627d',1,'gko::experimental::mpi::window']]],
  ['unpack_14',['unpack',['../classgko_1_1experimental_1_1factorization_1_1Factorization.html#ad0163a75274ff8054cc4d93732d82501',1,'gko::experimental::factorization::Factorization']]],
  ['unsupportedmatrixproperty_15',['UnsupportedMatrixProperty',['../classgko_1_1UnsupportedMatrixProperty.html',1,'gko::UnsupportedMatrixProperty'],['../classgko_1_1UnsupportedMatrixProperty.html#a38d858283d1e7e4a852c93baf79e7217',1,'gko::UnsupportedMatrixProperty::UnsupportedMatrixProperty()']]],
  ['update_16',['update',['../classgko_1_1stop_1_1Criterion.html#a47e22c46eaa742d709dcbf0d26d93e6c',1,'gko::stop::Criterion']]],
  ['update_5fvalues_17',['update_values',['../classgko_1_1matrix_1_1Csr_1_1multiply__reuse__info.html#aa8b9bb2b8ffc1e345663c4780897ed79',1,'gko::matrix::Csr::multiply_reuse_info::update_values()'],['../classgko_1_1matrix_1_1Csr_1_1multiply__add__reuse__info.html#a97921c3b4c3005a51e5a3fc91978f6c2',1,'gko::matrix::Csr::multiply_add_reuse_info::update_values()'],['../classgko_1_1matrix_1_1Csr_1_1scale__add__reuse__info.html#a966159aa1adb984d1b274e30a022a17c',1,'gko::matrix::Csr::scale_add_reuse_info::update_values()'],['../structgko_1_1matrix_1_1Csr_1_1permuting__reuse__info.html#a335568a4da6c11cff5dc7adbd347b4ce',1,'gko::matrix::Csr::permuting_reuse_info::update_values()']]],
  ['updater_18',['Updater',['../classgko_1_1stop_1_1Criterion_1_1Updater.html',1,'gko::stop::Criterion::Updater'],['../classgko_1_1stop_1_1Criterion_1_1Updater.html#aa8356e2fbfaf46cab62d8f8a905ab8bd',1,'gko::stop::Criterion::Updater::Updater()']]],
  ['uppertrs_19',['UpperTrs',['../classgko_1_1solver_1_1UpperTrs.html',1,'gko::solver::UpperTrs&lt; ValueType, IndexType &gt;'],['../classgko_1_1solver_1_1UpperTrs.html#a9fc8a602b284e8923b6a30135c84c437',1,'gko::solver::UpperTrs::UpperTrs(const UpperTrs &amp;)'],['../classgko_1_1solver_1_1UpperTrs.html#a97322e2b1e6bcce67f074f7fc5dd7cd1',1,'gko::solver::UpperTrs::UpperTrs(UpperTrs &amp;&amp;)']]],
  ['uppertrs_3c_20value_5ftype_2c_20index_5ftype_20_3e_20',['UpperTrs&lt; value_type, index_type &gt;',['../classgko_1_1solver_1_1UpperTrs.html',1,'gko::solver']]],
  ['uppertrs_3c_20valuetype_2c_20indextype_20_3e_21',['UpperTrs&lt; ValueType, IndexType &gt;',['../classgko_1_1solver_1_1UpperTrs.html',1,'gko::solver']]],
  ['usage_22',['Advantages of this approach and usage',['../group__LinOp.html#linop_3',1,'']]],
  ['use_20of_20macros_20vs_20functions_23',['Use of macros vs functions',['../contributing_guidelines.html#autotoc_md49',1,'']]],
  ['usecomposition_24',['UseComposition',['../classgko_1_1UseComposition.html',1,'gko']]],
  ['usecomposition_3c_20default_5fprecision_20_3e_25',['UseComposition&lt; default_precision &gt;',['../classgko_1_1UseComposition.html',1,'gko']]],
  ['usecomposition_3c_20valuetype_20_3e_26',['UseComposition&lt; ValueType &gt;',['../classgko_1_1UseComposition.html',1,'gko']]],
  ['user_27',['user',['../namespacegko_1_1log.html#a15f71654c6c4f4defc95f9359343fa27aee11cbb19052e40b07aac0ca060c23ee',1,'gko::log']]],
  ['user_5frange_28',['user_range',['../classgko_1_1log_1_1ProfilerHook.html#a4d0e1e93d993f5074d60276359faadd8',1,'gko::log::ProfilerHook']]],
  ['using_20batchcg_20in_20ginkgo_29',['Example: using BatchCG in Ginkgo',['../classgko_1_1batch_1_1BatchLinOpFactory.html#autotoc_md71',1,'']]],
  ['using_20cg_20in_20ginkgo_30',['Example: using CG in Ginkgo',['../classgko_1_1LinOpFactory.html#autotoc_md74',1,'']]],
  ['using_20ctest_31',['Using CTest',['../testing_ginkgo.html#autotoc_md10',1,'']]],
  ['using_20library_20classes_32',['Using library classes',['../contributing_guidelines.html#autotoc_md22',1,'']]],
  ['using_20make_20quick_5ftest_33',['Using make quick_test',['../testing_ginkgo.html#autotoc_md9',1,'']]],
  ['using_20make_20test_34',['Using make test',['../testing_ginkgo.html#autotoc_md8',1,'']]],
  ['using_20ssget_20to_20fetch_20the_20matrices_35',['2: Using ssget to fetch the matrices',['../benchmarking_ginkgo.html#autotoc_md12',1,'']]]
];
